@@ -116,10 +116,6 @@
   retval
 }
 
-.clusterize <- function(x, tolerance) {
-  dbscan::dbscan(x, eps = tolerance, minPts = 1)$cluster
-}
-
 #'@title Self-Updating Process Clustering
 #'
 #'@description 
@@ -128,7 +124,7 @@
 #'The algorithm mimics the process of gravitational attraction iteratively that eventually merges the samples into clusters on the sample space. 
 #'During the iterations, all samples continue moving until the system becomes stable.
 #'
-#'@param x matrix. Each row is an instance of the data.
+#'@param x data matrix. Each row is an instance of the data.
 #'@param r numeric vector or \code{NULL}. The parameter \eqn{r} of the self-updating process.
 #'@param rp numeric vector or \code{NULL}. If \code{r} is \code{NULL}, then \code{rp} will be used. 
 #'The corresponding \code{r} is the \code{rp}-percentile of the pairwise distances of the data. 
@@ -136,14 +132,14 @@
 #'@param t either numeric vector, list of function, or one of \code{"static" or "dynamic"}. The parameter \eqn{T(t)} of the self-updating process.
 #'@param tolerance numeric value. The threshold of convergence.
 #'@param cluster.tolerance numeric value. After iterations, if the distance of two points are smaller than \code{cluster.tolerance},
-#'then they are specified as the same cluster.
+#'then they are identified as in the same cluster.
 #'@param drop logical value. Whether to delete the list structure if its length is 1.
 #'@param implementation eithor \code{"R"}, \code{"cpp"} or \code{"cpp2"}. Choose the engine to calculate result.
 #'The \code{"cpp2"} parallelly computes the distance in C++ with OpenMP, which is not supported under OS X, and uses the early-stop to speed up calculation.
 #'@param verbose logical value. Whether to show the iteration history.
 #'
 #'@details
-#'Please check the vignettes via \code{vignettes("supc", package = "supc")} for details.
+#'Please check the vignettes via \code{vignette("supc", package = "supc")} for details.
 #'
 #'@return
 #'\code{supc1} returns a list of objects of \link{class} "supc".
@@ -211,7 +207,7 @@ supc1 <- function(
   cluster.tolerance = 10 * tolerance, 
   drop = TRUE, 
   implementation = c("cpp", "R", "cpp2"), 
-  verbose = FALSE
+  verbose = (nrow(x) > 10000)
   ) {
   parameters <- .get.parameters(x, r, rp, t)
   cl.raw <- switch(
@@ -253,29 +249,29 @@ supc1 <- function(
 #'@title Randomized Self-Updating Process Clustering
 #'
 #'@description 
-#'The Randomized Self-Updating Process Clustering(randomized SUPC) is a modification of the original SUPC algorithm. 
-#'The randomized SUPC randomly generates the partition of the instances during each iterations. 
-#'The self updating process is conducted independently in each partition in order to reduce the computation and the memory.
+#'The Randomized Self-Updating Process Clustering (randomized SUP) is a modification of the original SUP algorithm. 
+#'The randomized SUP randomly generates the partition of the instances during each iterations. 
+#'At each iteration, the self updating process is conducted independently in each partition in order to reduce the computation and the memory.
 #'
-#'@param x matrix. Each row is an instance of the data.
+#'@param x data matrix. Each row is an instance of the data.
 #'@param r numeric vector or \code{NULL}. The parameter \eqn{r} of the self-updating process.
 #'@param rp numeric vector or \code{NULL}. If \code{r} is \code{NULL}, then \code{rp} will be used. 
 #'The corresponding \code{r} is the \code{rp}-percentile of the pairwise distances of the data. 
 #'If both \code{r} and \code{rp} are \code{NULL}, then the default value is \code{rp = c(0.0005, 0.001, 0.01, 0.1, 0.3)}.
 #'@param t either numeric vector, list of function, or one of \code{"static" or "dynamic"}. The parameter \eqn{T(t)} of the self-updating process.
-#'@param k integer value. The size of the partition.
+#'@param k integer value. The number of the partitions.
 #'@param groups list. The first element is the partition of the first iteration, and the second element is the partition
 #'of the second iteration, etc. If the number of the iteration exceeds \code{length(groups)}, then new partition will be 
 #'generated.
 #'@param tolerance numeric value. The threshold of convergence.
 #'@param cluster.tolerance numeric value. After iterations, if the distance of two points are smaller than \code{cluster.tolerance},
-#'then they are specified as the same cluster.
+#'then they are identified as in the same cluster.
 #'@param drop logical value. Whether to delete the list structure if its length is 1.
 #'@param implementation eithor \code{"R"} or \code{"cpp"}. Choose the engine to calculate result.
 #'@param verbose logical value. Whether to show the iteration history.
 #'
 #'@details
-#'Please check the vignettes via \code{vignettes("supc", package = "supc")} for details.
+#'Please check the vignettes via \code{vignette("supc", package = "supc")} for details.
 #'
 #'@return
 #'\code{supc1} returns a list of objects of \link{class} "supc".
@@ -294,42 +290,46 @@ supc1 <- function(
 #'
 #'@examples
 #'\dontrun{
-#'set.seed(1)
-#'X <- local({
-#'  mu <- list(
-#'    x = c(0, 2, 1, 6, 8, 7, 3, 5, 4),
-#'    y = c(0, 0, 1, 0, 0, 1, 3, 3, 4)
-#'  )
-#'  X <- lapply(1:5, function(i) {
-#'    cbind(rnorm(9, mu$x, 1/5), rnorm(9, mu$y, 1/5))
-#'  })
-#'  X <- do.call(rbind, X)
-#'  n <- nrow(X)
-#'  X <- rbind(X, matrix(0, 20, 2))
-#'  k <- 1
-#'  while(k <= 20) {
-#'    tmp <- c(13*runif(1)-2.5, 8*runif(1)-2.5)
-#'    y1 <- mu$x - tmp[1]
-#'    y2 <- mu$y - tmp[2]
-#'    y <- sqrt(y1^2+y2^2)
-#'    if (min(y)> 2){
-#'      X[k+n,] <- tmp
-#'      k <- k+1
+#'# The shape data has a structure of five clusters and a number of noise data points.
+#'makecircle=function(N, seed){
+#'  n=0
+#'  x=matrix(NA, nrow=N, ncol=2)
+#'  while (n<N){
+#'    tmp=runif(2, min=0, max=1)*2-1
+#'    if (sum(tmp^2)<1) {
+#'       n=n+1
+#'       x[n,]=tmp
 #'    }
 #'  }
-#'  X
-#'})
-#'X.supcs <- supc.random(X, r = c(0.9, 1.7, 2.5), t = "dynamic", k = 2)
-#'X.supcs$cluster
-#'plot(X.supcs[[1]], type = "heatmap", major.size = 2)
-#'plot(X.supcs[[2]], type = "heatmap", col = cm.colors(24), major.size = 5)
+#'  return(x)
+#'}
 #'
-#'X.supcs <- supc.random(X, k = 2, r = c(1.7, 2.5), t = list(
-#'  function(t) {1.7 / 20 + exp(t) * (1.7 / 50)},
-#'  function(t) {exp(t)}
-#'))
-#'plot(X.supcs[[1]], type = "heatmap", major.size = 2)
-#'plot(X.supcs[[2]], type = "heatmap", col = cm.colors(24), major.size = 5)
+#'makedata <- function(ns, seed) {
+#'  size=c(10,3,3,1,1)
+#'  mu=rbind(c(-0.3, -0.3), c(-0.55, 0.8), c(0.55, 0.8), c(0.9, 0), c(0.9, -0.6))
+#'  sd=rbind(c(0.7, 0.7), c(0.45, 0.2), c(0.45, 0.2), c(0.1, 0.1), c(0.1, 0.1))
+#'  x=NULL
+#'
+#'  for (i in 1:5){
+#'     tmp=makecircle(ns*size[i], seed+i)
+#'     tmp[,1]=tmp[,1]*sd[i,1]+mu[i,1]
+#'     tmp[,2]=tmp[,2]*sd[i,2]+mu[i,2]
+#'     x=rbind(x, tmp)
+#'  }
+#'  
+#'  tmp=runif(floor(ns/3), min=0, max=1)/5-0.1
+#'  tmp=cbind(tmp, 0.8*rep(1, floor(ns/3)))
+#'  x=rbind(x, tmp)
+#'  x=rbind(x, matrix(1, nrow=2*ns, ncol=2)*2-1)
+#'  return(x)
+#'}
+#'
+#'shape1 <- makedata(5000, 1000)
+#'dim(shape1)
+#'plot(shape1)
+#'
+#'X.supc=supc.random(shape1, r=0.5, t="dynamic", k = 500)
+#'plot(shape1, col=X.supc$cluster)
 #'}
 #'
 #'@references
@@ -346,7 +346,7 @@ supc.random <- function(
   cluster.tolerance = 10 * tolerance, 
   drop = TRUE, 
   implementation = c("cpp", "R"), 
-  verbose = FALSE
+  verbose = (nrow(x) > 10000)
   ) {
   parameters <- .get.parameters(x, r, rp, t)
   if (is.null(groups)) parameters$groups <- rep(list(NULL), length(parameters$tau)) else {
